==> elgg-2.3.12.zip: elgg-2.3.12/mod/bookmarks/languages/fr.php <==
<?php
return array(

	/**
	 * Menu items and titles
	 */
	'bookmarks' => "Signets",
	'bookmarks:add' => "Ajouter un signet",
	'bookmarks:edit' => "Modifier le signet",
	'bookmarks:owner' => "Les signets de %s",
	'bookmarks:friends' => "Signets des contacts",
	'bookmarks:everyone' => "Tous les signets du site",
	'bookmarks:this' => "Mettre cette page en signet",
	'bookmarks:this:group' => "Mettre en signet dans %s",
	'bookmarks:bookmarklet' => "Installer le \"bookmarklet\"",
	'bookmarks:bookmarklet:group' => "Installer le \"bookmarklet\" du groupe",
	'bookmarks:inbox' => "Boîte de réception des signets",
	'bookmarks:address' => "Adresse web (URL) de la ressource à ajouter à vos signets",
	'bookmarks:none' => 'Aucun signet',

	'bookmarks:notify:summary' => 'Nouveau signet intitulé %s',
	'bookmarks:notify:subject' => 'Nouveau signet: %s',
	'bookmarks:notify:body' =>
'%s a ajouté un nouveau signet: %s

Adresse: %s

%s

Voir et commenter ce signet: 
%s
',

	'bookmarks:delete:confirm' => "Confirmez-vous vouloir supprimer cette ressource ?",

	'bookmarks:numbertodisplay' => 'Nombre de signets à afficher',

	'river:create:object:bookmarks' => '%s a mis en signet %s',
	'river:comment:object:bookmarks' => '%s a commenté le signet %s',
	'bookmarks:river:annotate' => 'un commentaire sur ce signet',
	'bookmarks:river:item' => 'un élément',

	'item:object:bookmarks' => 'Signets',

	'bookmarks:group' => 'Signets du groupe',
	'bookmarks:enablebookmarks' => 'Activer les signets du groupe',
	'bookmarks:nogroup' => 'Ce groupe n\'a pas encore de signet',
	
	/**
	 * Widget and bookmarklet
	 */
	'bookmarks:widget:description' => "Ce widget affiche vos derniers signets.",

	'bookmarks:bookmarklet:description' =>
			"Un \"bookmarklet\" est un type de bouton ou de lien spécial que vous enregistrez dans la barre de liens de votre navigateur. Il vous permet d'enregistrer rapidement tout type de ressource que vous trouvez sur internet dans vos signets. Pour le mettre en place, faites glisser le bouton ci-dessous dans la barre de liens de votre navigateur :",

	'bookmarks:bookmarklet:descriptionie' =>
			"Si vous utilisez Internet Explorer, faites un clic droit sur le bouton et ajoutez-le dans vos favoris, puis dans votre barre de liens.",

	'bookmarks:bookmarklet:description:conclusion' =>
			"Vous pouvez mettre en signet n'importe quelle page à tout moment en cliquant sur le bouton de votre navigateur.",

	/**
	 * Status messages
	 */

	'bookmarks:save:success' => "Votre élément a bien été mis en signet.",
	'bookmarks:delete:success' => "Votre signet a bien été supprimé.",

	/**
	 * Error messages
	 */

	'bookmarks:save:failed' => "Votre signet n'a pas pu être enregistré. Vérifiez que le titre et le lien sont corrects et réessayez.",
	'bookmarks:save:invalid' => "L’adresse du signet est invalide et ne peut donc pas être enregistrée.",
	'bookmarks:delete:failed' => "Votre signet n'a pas pu être supprimé. Merci de réessayer.",
	'bookmarks:unknown_bookmark' => 'Impossible de trouver le signet spécifié',
);

==> elgg-3.3.20.zip: elgg-3.3.20/mod/bookmarks/languages/fr.php <==
<?php
/**
 * Translation file
 *
 * Note: don't change the return array to short notation because Transifex can't handle those during `tx push -s`
 */

return array(

	/**
	 * Menu items and titles
	 */
	'item:object:bookmarks' => 'Signets',
	'collection:object:bookmarks' => 'Signets',
	'collection:object:bookmarks:group' => 'Signets du groupe',
	'collection:object:bookmarks:all' => "Tous les signets du site",
	'collection:object:bookmarks:owner' => "Signets de %s",
	'collection:object:bookmarks:friends' => "Signets des contacts",
	'add:object:bookmarks' => "Ajouter un signet",
	'edit:object:bookmarks' => "Modifier le signet",

	'bookmarks:this' => "Mettre cette page en signet",
	'bookmarks:this:group' => "Mettre en signet dans %s",
	'bookmarks:bookmarklet' => "Installer le \"bookmarklet\"",
	'bookmarks:bookmarklet:group' => "Installer le \"bookmarklet\" du groupe",
	'bookmarks:address' => "Adresse web (URL) de la ressource à ajouter à vos signets",
	'bookmarks:none' => 'Aucun signet',

	'bookmarks:notify:summary' => 'Nouveau signet intitulé %s',
	'bookmarks:notify:subject' => 'Nouveau signet: %s',
	'bookmarks:notify:body' =>
'%s a ajouté un nouveau signet : %s

Adresse : %s

%s

Voir et commenter ce signet :
%s
',

	'bookmarks:numbertodisplay' => 'Nombre de signets à afficher',

	'river:object:bookmarks:create' => '%s a mis en signet %s',
	'river:object:bookmarks:comment' => '%s a commenté le signet  %s',

	'groups:tool:bookmarks' => 'Activer les signets du groupe',
	
	/**
	 * Widget and bookmarklet
	 */
	'widgets:bookmarks:name' => 'Signets',
	'widgets:bookmarks:description' => "Affiche vos derniers signets.",

	'bookmarks:bookmarklet:description' =>
			"Un \"bookmarklet\" est un type de bouton ou de lien spécial que vous enregistrez dans la barre de liens de votre navigateur. Il vous permet d'enregistrer rapidement tout type de ressource que vous trouvez sur internet dans vos signets. Pour le mettre en place, faites glisser le bouton ci-dessous dans la barre de liens de votre navigateur :",

	'bookmarks:bookmarklet:descriptionie' =>
			"Si vous utilisez Internet Explorer, faites un clic droit sur le bouton et ajoutez-le dans vos favoris, puis dans votre barre de liens.",

	'bookmarks:bookmarklet:description:conclusion' =>
			"Vous pouvez mettre en signet n'importe quelle page à tout moment en cliquant sur le bouton de votre navigateur.",

	/**
	 * Status messages
	 */

	'bookmarks:save:success' => "Votre élément a bien été mis en signet.",
	'entity:delete:object:bookmarks:success' => "Ce signet a été supprimé.",

	/**
	 * Error messages
	 */

	'bookmarks:save:failed' => "Votre signet n'a pas pu être enregistré. Vérifiez que le titre et le lien sont corrects et réessayez.",
	'bookmarks:unknown_bookmark' => 'Impossible de trouver le signet spécifié',
);
